@@ -57,7 +57,7 @@ def get_account(fn, id, requisition, LOGGER, ignored=[], config={}):
     try:
         account = fn(id)
         account = account.get("account", {})
-    except requests.exceptions.HTTPError as error:
+    except Exception as error:
         LOGGER.error("Unable to fetch account details from Nordigen: %s", error)
         return
 
@@ -103,12 +103,22 @@ def matched_requisition(ref, requisitions):
     return {}
 
 
-def get_or_create_requisition(fn_create, fn_initiate, requisitions, reference, enduser_id, aspsp_id, LOGGER):
+def get_or_create_requisition(fn_create, fn_initiate, fn_remove, requisitions, reference, enduser_id, aspsp_id, LOGGER):
     requisition = matched_requisition(reference, requisitions)
+    if requisition and requisition.get("status") in ["EX", "SU"]:
+        fn_remove(
+            **{
+                "id": requisition["id"],
+            }
+        )
+
+        LOGGER.info("Requisition was in failed state, removed :%s", requisition)
+        requisition = None
+
     if not requisition:
         requisition = fn_create(
             **{
-                "redirect": "http://127.0.0.1/",
+                "redirect": "https://127.0.0.1/",
                 "reference": reference,
                 "enduser_id": enduser_id,
                 "agreements": [],
@@ -117,14 +127,18 @@ def get_or_create_requisition(fn_create, fn_initiate, requisitions, reference, e
         LOGGER.debug("No requisition found, created :%s", requisition)
 
     if requisition.get("status") != "LN":
-        init = fn_initiate(
-            **{
-                "id": requisition["id"],
-                "aspsp_id": aspsp_id,
-            }
-        )
-        LOGGER.info("Authenticate and accept connection and restart :%s", init["initiate"])
-        return {}
+        print(requisition)
+        requisition = {
+            **requisition,
+            **fn_initiate(
+                **{
+                    "id": requisition["id"],
+                    "aspsp_id": aspsp_id,
+                }
+            ),
+            "requires_auth": True,
+        }
+        LOGGER.info("Authenticate and accept connection and restart :%s", requisition["initiate"])
 
     return requisition
 
@@ -142,6 +156,7 @@ def get_accounts(client, configs, LOGGER, CONST):
         requisition = get_or_create_requisition(
             fn_create=client.requisitions.create,
             fn_initiate=client.requisitions.initiate,
+            fn_remove=client.requisitions.remove,
             requisitions=requisitions,
             reference=get_reference(**config),
             aspsp_id=config[CONST["ASPSP_ID"]],
@@ -149,18 +164,28 @@ def get_accounts(client, configs, LOGGER, CONST):
             LOGGER=LOGGER,
         )
 
-        LOGGER.debug("Handling requisition :%s", requisition.get("id"))
-        for account_id in requisition.get("accounts", []):
-            accounts.append(
-                get_account(
-                    fn=client.account.details,
-                    id=account_id,
-                    requisition=requisition,
-                    LOGGER=LOGGER,
-                    ignored=config[CONST["IGNORE_ACCOUNTS"]],
-                    config=config,
-                )
+        accounts.extend(handle_requisition(client, config, LOGGER, CONST, requisition))
+    return accounts
+
+
+def handle_requisition(client, config, LOGGER, CONST, requisition):
+    """Handle requisition."""
+    if requisition.get("requires_auth"):
+        return [requisition]
+
+    accounts = []
+    LOGGER.debug("Handling requisition :%s", requisition.get("id"))
+    for account_id in requisition.get("accounts", []):
+        accounts.append(
+            get_account(
+                fn=client.account.details,
+                id=account_id,
+                requisition=requisition,
+                LOGGER=LOGGER,
+                ignored=config[CONST["IGNORE_ACCOUNTS"]],
+                config=config,
             )
+        )
 
     return accounts
 
